==> pdfadd_2.0.orig.tar.gz: pdfadd-2.0/asyeditor.cpp <==
/***************************************************************************
 *   copyright       : (C) 2012-2014 by Pascal Brachet                     *
 *   http://www.xm1math.net/pdfadd/                                        *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/


#include <QAction>
#include <QMenu>
#include <QFileDialog>
#include <QMessageBox>
#include <QTextCodec>
#include <QTextStream>

#include "asyeditor.h"


AsyEditor::AsyEditor(QWidget *parent) : QTextEdit(parent)
{
highlighter = new Highlighter(document());
}
AsyEditor::~AsyEditor(){
}

void AsyEditor::contextMenuEvent(QContextMenuEvent *e)
{
QMenu *menu=new QMenu(this);
QAction *a;
a = menu->addAction(QString::fromUtf8("Copier"), this, SLOT(copy()));
a->setShortcut(Qt::CTRL+Qt::Key_C);
a->setEnabled(textCursor().hasSelection());
a = menu->addAction(QString::fromUtf8("Sélectionner tout"), this, SLOT(selectAll()));
a->setShortcut(Qt::CTRL+Qt::Key_A);
a->setEnabled(!document()->isEmpty());
menu->addSeparator();
a = menu->addAction(QString::fromUtf8("Enregistrer (UTF-8)"), this, SLOT(save()));
a->setShortcut(Qt::CTRL+Qt::Key_E);
a->setEnabled(!document()->isEmpty());
menu->exec(e->globalPos());
delete menu;
}

void AsyEditor::save()
{
QString fileName = QFileDialog::getSaveFileName(this,QString::fromUtf8("Enregistrer sous"),QDir::homePath(),QString::fromUtf8("Fichier asymptote (*.asy)"));
if (fileName.isEmpty()) return;
QFile file(fileName);
if (!file.open(QFile::WriteOnly | QFile::Text)) 
  {
  QMessageBox::warning(this, QString::fromUtf8("PdfAdd"),
			  QString::fromUtf8("Impossible d'écrire le fichier %1:\n%2.")
			  .arg(fileName)
			  .arg(file.errorString()));
  return;
  }
QTextCodec *codec = QTextCodec::codecForName("UTF-8");
QTextStream out(&file);
out.setCodec(codec);
out << this->toPlainText();
file.close();
}

==> pdfadd_2.0.1.orig.tar.gz: pdfadd-2.0.1/asyeditor.cpp <==
/***************************************************************************
 *   copyright       : (C) 2012-2021 by Pascal Brachet                     *
 *   https://www.xm1math.net/pdfadd/                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   @license GPL-2.0+ <https://spdx.org/licenses/GPL-2.0+.html>           *
 ***************************************************************************/


#include <QAction>
#include <QMenu>
#include <QFileDialog>
#include <QMessageBox>
#include <QTextStream>

#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
    #include <QtCore/QTextCodec>
#else
    #include <QtCore5Compat/QTextCodec>
#endif

#include "asyeditor.h"


AsyEditor::AsyEditor(QWidget *parent) : QTextEdit(parent)
{
highlighter = new Highlighter(document());
}
AsyEditor::~AsyEditor(){
}

void AsyEditor::contextMenuEvent(QContextMenuEvent *e)
{
QMenu *menu=new QMenu(this);
QAction *a;
a = menu->addAction(QString::fromUtf8("Copier"), this, SLOT(copy()));
a->setShortcut(Qt::CTRL | Qt::Key_C);
a->setEnabled(textCursor().hasSelection());
a = menu->addAction(QString::fromUtf8("Sélectionner tout"), this, SLOT(selectAll()));
a->setShortcut(Qt::CTRL | Qt::Key_A);
a->setEnabled(!document()->isEmpty());
menu->addSeparator();
a = menu->addAction(QString::fromUtf8("Enregistrer (UTF-8)"), this, SLOT(save()));
a->setShortcut(Qt::CTRL | Qt::Key_E);
a->setEnabled(!document()->isEmpty());
menu->exec(e->globalPos());
delete menu;
}

void AsyEditor::save()
{
QString fileName = QFileDialog::getSaveFileName(this,QString::fromUtf8("Enregistrer sous"),QDir::homePath(),QString::fromUtf8("Fichier asymptote (*.asy)"));
if (fileName.isEmpty()) return;
QFile file(fileName);
if (!file.open(QFile::WriteOnly | QFile::Text)) 
  {
  QMessageBox::warning(this, QString::fromUtf8("PdfAdd"),
			  QString::fromUtf8("Impossible d'écrire le fichier %1:\n%2.")
			  .arg(fileName)
			  .arg(file.errorString()));
  return;
  }
QTextCodec *codec = QTextCodec::codecForName("UTF-8");
file.write(codec->fromUnicode(this->toPlainText()));
//QTextStream out(&file);
//out.setCodec(codec);
//out << this->toPlainText();
file.close();
}
